@@ -1,10 +1,18 @@
 # -*- coding: utf-8 -*-
 
-from unittest.mock import patch
+from __future__ import unicode_literals
+
+try:
+    from unittest.mock import patch
+except ImportError:
+    from mock import patch
+
 import unittest
 import logging
 import collections
 
+import six
+
 import react
 from react.react import _DEFINE_GLOBALS_SCRIPT
 
@@ -94,6 +102,9 @@ class ReactTest(unittest.TestCase):
         self.assertEqual(
             '{"foo": "foo", "bar": 1}',
             react.React.to_json('{"foo": "foo", "bar": 1}'))
+        self.assertIsInstance(
+            react.React.to_json('{"foo": "foo", "bar": 1}'),
+            six.text_type)
 
     def test_to_dict(self):
         """
