@@ -1,12 +1,20 @@
 # -*- coding: utf-8 -*-
 
-from unittest.mock import patch
+from __future__ import unicode_literals
+
+try:
+    from unittest.mock import patch
+except ImportError:
+    from mock import patch
+
 import unittest
 import logging
 import os
 import tempfile
 from contextlib import contextmanager
 
+import six
+
 import react
 from react import utils
 
@@ -18,8 +26,8 @@ _global = '__global'
 
 @contextmanager
 def js_file(data):
-    if isinstance(data, str):
-        data = bytes(data, 'utf-8')
+    if isinstance(data, six.text_type):
+        data = data.encode('utf-8')
 
     temp = tempfile.NamedTemporaryFile(delete=False)
     temp.write(data)
